@@ -833,12 +833,20 @@ def _fetch_bundle_contents_blob(uuid, path=''):
     # We should redirect to the Blob Storage URL if the following conditions are met:
     should_redirect_url = (
         support_redirect == 1
-        and location_info["storage_type"] == StorageType.AZURE_BLOB_STORAGE.value  # On Blob Storage
+        and location_info["storage_type"]
+        in (StorageType.AZURE_BLOB_STORAGE.value, StorageType.GCS_STORAGE.value)
         and path == ''  # No subpath
         and request_accepts_gzip_encoding()  # Client accepts gzip encoding
         and not (byte_range or head_lines or tail_lines)  # We're requesting the entire file
     )
 
+    # We don't support bypassing server for single-file bundles located on GCS requested
+    if (
+        target_info['type'] == 'file'
+        and location_info["storage_type"] == StorageType.GCS_STORAGE.value
+    ):
+        should_redirect_url = False
+
     if target_info['type'] == 'directory':
         if byte_range:
             abort(http.client.BAD_REQUEST, 'Range not supported for directory blobs.')
@@ -910,7 +918,7 @@ def _fetch_bundle_contents_blob(uuid, path=''):
     if should_redirect_url:
         # Redirect to SAS URL on Blob Storage.
         assert fileobj is None  # We should not be returning any other contents.
-        sas_url = local.download_manager.get_target_sas_url(
+        download_url = local.download_manager.get_target_download_url(
             target,
             # We pass these parameters to set the Content-Type, Content-Encoding, and
             # Content-Disposition headers that are set on the Blob Storage response.
@@ -924,8 +932,10 @@ def _fetch_bundle_contents_blob(uuid, path=''):
         # Azurite through http://localhost, but rather only through http://azurite.
         if LOCAL_USING_AZURITE:
             if get_request_source() == RequestSource.LOCAL_DOCKER:
-                sas_url = sas_url.replace("localhost", "azurite", 1)
-        return redirect(sas_url)
+                download_url = download_url.replace("localhost", "azurite", 1)
+        return redirect(
+            download_url
+        )  # the client receive http 303, and send the request to new url
     return fileobj
 
 
