@@ -41,6 +41,8 @@ ALL_SERVICES = DEFAULT_SERVICES + [
     'worker-manager-cpu',
     'worker-manager-gpu',
     'worker2',
+    'worker-preemptible',
+    'worker-preemptible2',
 ]
 
 ALL_NO_SERVICES = [
@@ -59,6 +61,8 @@ SERVICE_TO_IMAGE = {
     'monitor': 'server',
     'worker': 'worker',
     'worker2': 'worker',
+    'worker-preemptible': 'worker',
+    'worker-preemptible2': 'worker',
 }
 
 # Max timeout in seconds to wait for request to a service to get through
@@ -477,17 +481,17 @@ for worker_manager_type in ['cpu', 'gpu']:
         CodalabArg(
             name=f'worker_manager_{worker_manager_type}_kubernetes_cluster_host',
             type=str,
-            help='Host address of the Kubernetes cluster for the Kubernetes worker manager',
+            help=f'Host address of the Kubernetes cluster for the {worker_manager_type} Kubernetes worker manager',
         ),
         CodalabArg(
             name=f'worker_manager_{worker_manager_type}_kubernetes_auth_token',
             type=str,
-            help='Kubernetes cluster authorization token for the Kubernetes worker manager',
+            help=f'Kubernetes cluster authorization token for the {worker_manager_type} Kubernetes worker manager',
         ),
         CodalabArg(
             name=f'worker_manager_{worker_manager_type}_kubernetes_cert_path',
             type=str,
-            help='Path to the generated SSL cert for the Kubernetes worker manager',
+            help=f'Path to the generated SSL cert for the {worker_manager_type} Kubernetes worker manager',
         ),
     ]
 
@@ -953,6 +957,8 @@ class CodalabServiceManager(object):
         else:
             self.bring_up_service('worker')
         self.bring_up_service('worker2')
+        self.bring_up_service('worker-preemptible')
+        self.bring_up_service('worker-preemptible2')
 
         self.bring_up_service('monitor')
 
